<?php

// XP Index Directory:
// Relative position to the webroot
$XPIndexDir = '/XPindex';

// UserDirs:
// The directory where the userdirs are created (default: /home).
$UserDirs = '/home';

// ApacheUserDir:
// This is the same entry as can be found in the apache config file (default: public_html).
$ApacheUserDir = 'public_html';

// ApacheReadmeName:
// This is the same entry as can be found in the apache config file (default: README.html).
$ApacheReadmeName = 'README.html';

// XP Index Theme:
//
// default, olive, silver
$XPIndexTheme = 'default';

// XP Index TaskBar
// never = never draw the taskbar
// readme = only draw the taskbar when there is an README.html file in the directory
// always = always draw the taskbar
$XPIndexTaskBar = 'readme';

// XP Index Language:
// nl = Dutch
// en = English
$XPIndexLanguage = nl;

// File descriptions:
$knownfiletypes = Array(
	'000000000'	=> Array(
		nl => 'Bovenliggende map',
		en => 'Parent folder'),
	'000000001'	=> Array(
		nl => 'Map',
		en => 'Folder'),
	'asf' => Array(
		nl => 'Windows Media Audio/Video-bestand',
		en => 'Windows Media Audio/Video File'),
	'avi' => Array(
		nl => 'Video Clip',
		en => 'Video Clip'),
	'bmp' => Array(
		nl => 'Bitmapafbeelding',
		en => 'Bitmap Image'),
	'css' => Array(
		nl => 'Document met trapgewijs opmaakmodel',
		en => 'CSS File'),
	'db' => Array(
		nl => 'Databasebestand',
		en => 'DBase File'),
	'dll' => Array(
		nl => 'Toepassingsuitbreiding',
		en => 'Application Extension'),
	'doc' => Array(
		nl => 'Microsoft Word-document',
		en => 'Microsoft Word-document'),
	'exe' => Array(
		nl => 'Toepassing',
		en => 'Application'),
	'gif' => Array(
		nl => 'GIF-afbeelding',
		en => 'GIF Image'),
	'gz' => Array(
		nl => 'GZip-archief',
		en => 'GZip Archive'),
	'htm' => Array(
		nl => 'HTML-document',
		en => 'HTML Document'),
	'html' => Array(
		nl => 'HTML-document',
		en => 'HTML Document'),
	'ini' => Array(
		nl => 'Configuratie-instellingen',
		en => 'Configuratie Settings'),
	'jpg' => Array(
		nl => 'JPEG-afbeelding',
		en => 'JPEG Image'),
	'jpeg' => Array(
		nl => 'JPEG-afbeelding',
		en => 'JPEG Image'),
	'js' => Array(
		nl => 'JScript Script-bestand',
		en => 'JScript Script File'),
	'jse' => Array(
		nl => 'JScript encoded Script-bestand',
		en => 'JScript encoded Script File'),
	'mp3' => Array(
		nl => 'MP3 media-bestand',
		en => 'MP3 Media File'),
	'mpe' => Array(
		nl => 'Film-bestand',
		en => 'Movie File'),
	'mpeg' => Array(
		nl => 'Film-bestand',
		en => 'Movie File'),
	'mpg' => Array(
		nl => 'Film-bestand',
		en => 'Movie File'),
	'pdf' => Array(
		nl => 'Adobe Acrobat Document',
		en => 'Adobe Acrobat Document'),
	'php' => Array(
		nl => 'PHP Script-bestand',
		en => 'PHP Script File'),
	'php3' => Array(
		nl => 'PHP3 Script-bestand',
		en => 'PHP3 Script File'),
	'php4' => Array(
		nl => 'PHP4 Script-bestand',
		en => 'PHP4 Script File'),
	'phps' => Array(
		nl => 'PHP Script Source-bestand',
		en => 'PHP Script Source File'),
	'phtml' => Array(
		nl => 'PHP Script-bestand',
		en => 'PHP Script File'),
	'png' => Array(
		nl => 'PNG-afbeelding',
		en => 'PNG Image'),
	'rar' => Array(
		nl => 'WinRAR-archief',
		en => 'WinRAR Archive'),
	'sql' => Array(
		nl => 'SQL Script-bestand',
		en => 'SQL Script File'),
	'tar' => Array(
		nl => 'Tarball-archief',
		en => 'Tarball Archive'),
	'tgz' => Array(
		nl => 'GZip Tarball-archief',
		en => 'GZip Tarball Archive'),
	'txt' => Array(
		nl => 'Tekstdocument',
		en => 'TXT File'),
	'xls' => Array(
		nl => 'Microsoft Excel-werkblad',
		en => 'Microsoft Excel-sheet'),
	'xml' => Array(
		nl => 'XML-document',
		en => 'XML Document'),
	'xsl' => Array(
		nl => 'XSL-opmaakmodel',
		en => 'XSL Document'),
	'xslt' => Array(
		nl => 'XSL Transformation',
		en => 'XSL Transformation'),
	'zip' => Array(
		nl => 'Gecomprimeerde map',
		en => 'Compressed folder')
);

//	File icons:
$icons = Array(
	'000000000'	=> 'mapup.png',
	'000000001'	=> 'map.png',
	'asf' => 'avi.png',
	'avi' => 'avi.png',
	'bmp' => 'bmp.png',
	'css' => 'ini.png',
	'db' => 'dll.png',
	'dll' => 'dll.png',
	'gz' => 'zip.png',
	'gif' => 'gif.png',
	'html' => 'html.png',
	'htm' => 'html.png',
	'ini' => 'ini.png',
	'jpg' => 'jpg.png',
	'jpeg' => 'jpg.png',
	'js' => 'js.png',
	'jse' => 'js.png',
	'mp3' => 'mp3.png',
	'mpe' => 'avi.png',
	'mpeg' => 'avi.png',
	'mpg' => 'avi.png',
	'pdf' => 'pdf.png',
	'php' => 'php.png',
	'php3' => 'php.png',
	'php4' => 'php.png',
	'phps' => 'php.png',
	'phtml' => 'php.png',
	'png' => 'gif.png',
	'rar' => 'rar.png',
	'shtm' => 'html.png',
	'shtml' => 'html.png',
	'sql' => 'sql.png',
	'tar' => 'zip.png',
	'tgz' => 'zip.png',
	'txt' => 'txt.png',
	'xls' => 'xls.png',
	'xml' => 'xml.png',
	'xsl' => 'xsl.png',
	'xslt' => 'xslt.png',
	'zip' => 'zip.png'
);

$captions = Array(
	'file' => Array(
		nl => 'bestand',
		en => 'file'),
	'filename' => Array(
		nl => 'Naam',
		en => 'Filename'),
	'size' => Array(
		nl => 'Grootte',
		en => 'Size'),
	'type' => Array(
		nl => 'Type',
		en => 'Type'),
	'changed' => Array(
		nl => 'Gewijzigd op',
		en => 'Changed at'),
	'owner' => Array(
		nl => 'Eigenaar',
		en => 'Owner'),
	'group' => Array(
		nl => 'Groep',
		en => 'Group'),
	'attributes' => Array(
		nl => 'Kenmerken',
		en => 'Attributes'),
	'changed' => Array(
		nl => 'Gewijzigd op',
		en => 'Changed at'),
	'readme' => Array(
		nl => 'Readme',
		en => 'Readme')
);

?>